smb3itemtracker
===============

UI to handle tracking inventory in SMB3

All the code and assets were made by Lui_!
narfman0 just uselessly packaged it :)

Installation
------------

Navigate to the most recent versioned release here:

https://github.com/narfman0/smb3-item-tracker/tags

Download the zip and extract to your favorite directory.

License
-------

Copyright (c) 2023 Lui_, Jon Robison

See LICENSE for details
